@@ -1,16 +1,15 @@
 package Term::ExtendedColor;
 
-$VERSION  = '0.169';
+$VERSION  = '0.171';
 
 require Exporter;
 @ISA = 'Exporter';
-our @EXPORT = qw(uncolor get_colors fg bg clear lookup);
+our @EXPORT_OK = qw(uncolor get_colors fg bg clear lookup autoreset);
 
 # We need to access the autoreset function by using the fully qualified name.
 # If we try to import functions from @EXPORT_OK, the exported functions in
 #@EXPORT doesnt get exported at all, for some reason.
 # This is 'intended behaviour', according to #perl.
-our @EXPORT_OK = qw(autoreset);
 
 use strict;
 use Carp;
@@ -426,7 +425,7 @@ Term::ExtendedColor - Color screen output using extended escape sequences
 
 =head1 SYNOPSIS
 
-    use Term::ExtendedColor;
+    use Term::ExtendedColor qw(fg bg uncolor get_colors clear lookup);
 
     ## Foreground colors
 
@@ -505,6 +504,10 @@ Support is included for redefining colors - use with care, though.
 
 =head1 EXPORTS
 
+None by default.
+
+=head1 FUNCTIONS
+
 =head2 fg()
 
 Parameters: $string, integer | \@strings, \@integers
@@ -650,7 +653,7 @@ L<Term::ExtendedColor::Xresources>, L<Term::ANSIColor>
 
 =head1 COPYRIGHT
 
-Copyright 2010 Magnus Woldrich <magnus@trapd00r.se>. This program is free
+Copyright 2010, 2011 Magnus Woldrich <magnus@trapd00r.se>. This program is free
 software; you may redistribute it and/or modify it under the same terms as
 Perl itself.
 
